
/*------------------------------------------------------------------------------
********************************************************************************
* Lopez, Sautmann, Schaner
* Do Patients Value High-Quality Medical Care? 
* Experimental Evidence from Malaria Diagnosis and Treatment
********************************************************************************

** Analysis file creating tables and data based figures in the paper.
** This version: January, 2024

------------------------------------------------------------------------------*/

clear all
set more off
set matsize 5000
set maxvar 32767
version 14.2

graph set window fontface "Garamond"
		
*************************************************************************************************
* Users: Change this section the first time. 
*------------------------------------------

* Define paths: Put your computer's paths, inside the loop with your username.
*----------
	global path "C:/Users/wb614536/Downloads/LSS_info_replication_package"

	global data_final	= "$path/Data"
	global dofiles_fig  = "$path/Do_Files/Figures"
	global dofiles_tab  = "$path/Do_Files/Tables"
	global dofiles_admin= "$path/Do_Files/Stata admin files"
	global tables 		= "$path/Tables"
	global graphs 		= "$path/Figures"

	sysdir set PLUS "$path/Do_Files/ado"

*************************************************************************************************
* LOAD TABLES 
*************************************************************************************************

* LOAD PROGRAM
include "$dofiles_admin/LSS_info_TablePrograms.do"

* ADDITIONAL CONTROLS + CLUSTERING LEVEL
	global cont_lso "CC*"
	global cont_date "DD*"
	global cont_strat "SD*"
	global cluvar "info_strata"
	global clulevel "clinic-pair"
	global unit "cscomid"
	global unit_level "clinic"

* FORMAT/FOOTNOTES IN TEX	
include "$dofiles_admin/LSS_info_config_tables.do"

**********************************************************************************
* Make replicant datasets for bootstrapping.
* takes ~6 MIN to run
**********************************************************************************

include "$dofiles_admin/LSS_info_make_bootstrap_repsets.do"

********************************************************************************
* MAIN TABLES
********************************************************************************		

*------------------------------------------------------------------------------
* Randomization Verification 
*------------------------------------------------------------------------------
include "$dofiles_tab/doc_balance_pre_training.do"

*------------------------------------------------------------------------------
* Effect of Extended Provider Training on Learning
* With and w/o additional controls
*------------------------------------------------------------------------------
include "$dofiles_tab/doc_post_training_trained.do" 

include "$dofiles_tab/doc_post_training_trained_nocont.do" 

*------------------------------------------------------------------------------
* Effect of Extended Provider Training and Patient Information on Malaria Testing at the Clinic
* With and w/o additional controls
*------------------------------------------------------------------------------
use "$data_final/LSS_info_DocPat_analysis_datasets_allcont.dta", clear

	include "$dofiles_tab/doc_mal_testing.do" 

*------------------------------------------------------------------------------
* Effect of Extended Provider Training and Patient Information on the Allocation of Malaria Treatment
* With and w/o additional controls
*------------------------------------------------------------------------------
use "$data_final/LSS_info_DocPat_analysis_datasets_allcont.dta", clear

	include "$dofiles_tab/doc_treat_allocn.do" 

*------------------------------------------------------------------------------
* Effect of Extended Provider Training and Patient Information on Patient Satisfaction
* With and w/o additional controls
*------------------------------------------------------------------------------
use "$data_final/LSS_info_DocPat_analysis_datasets_allcont.dta", clear

	include "$dofiles_tab/doc_patient_satisfaction.do" 

*------------------------------------------------------------------------------
* Effect of Extended Provider Training and Patient Information on Patient Satisfaction
* With and w/o additional controls
*------------------------------------------------------------------------------
use "$data_final/LSS_info_DocPat_analysis_datasets_allcont.dta", clear

	include "$dofiles_tab/doc_patient_satisfaction_priorhet_match.do" 

	
********************************************************************************
* MAIN FIGURES
********************************************************************************		

*------------------------------------------------------------------------------
* bar chart: Malaria Incident, Antimalarial Prescriptions, and Match Between Underlying Illness and Treatment
*------------------------------------------------------------------------------		
use "$data_final/LSS_info_DocPat_analysis_datasets_allcont.dta", clear

	include "$dofiles_fig/bar_misallocation.do"		

*------------------------------------------------------------------------------
* stacked bar: Effect of Extended Provider Training on Testing at the Clinic
*------------------------------------------------------------------------------
use "$data_final/LSS_info_DocPat_analysis_datasets_allcont.dta", clear

	include "$dofiles_fig/bar_doc_testing.do"

*------------------------------------------------------------------------------
* lpoly: Effect of Extended Provider Training on Allocation of Malaria Treatment at the Clinic
*------------------------------------------------------------------------------
use "$data_final/LSS_info_DocPat_analysis_datasets_allcont.dta", clear

	include "$dofiles_fig/lpoly_testsXpredpos_bootstrap.do"

*------------------------------------------------------------------------------
* bar chart: Effect of Extended Training on Perceived Malaria Risk, by Home RDT Result
*------------------------------------------------------------------------------
use "$data_final/LSS_info_DocPat_analysis_datasets_allcont.dta", clear

	include "$dofiles_fig/bar_impact_di_pat_knowledge.do"		

*------------------------------------------------------------------------------
* CDFs: Effect of Extended Provider Training on Patient Satisfaction
*------------------------------------------------------------------------------
use "$data_final/LSS_info_DocPat_analysis_datasets_allcont.dta", clear

	include "$dofiles_fig/cdfs_patient_satisfaction.do"		

		
*******************************************************************************
* APPENDIX MATERIAL
*******************************************************************************
	
*------------------------------------------------------------------------------
* APPENDIX: lpoly: Effect of Extended Provider Training on Patient Satisfaction
*------------------------------------------------------------------------------
use "$data_final/LSS_info_DocPat_analysis_datasets_allcont.dta", clear

	include "$dofiles_fig/Appendix/lpoly_satisfactionXpredpos_bootstrap.do"
	
*------------------------------------------------------------------------------
* APPENDIX: Provider Beliefs in the Control Group: Health Worker Post-Intervention Survey
*------------------------------------------------------------------------------
use "$data_final/LSS_info_DoctorEndlineInterview_allcont.dta", clear

	include "$dofiles_tab/Appendix/doc_control_group.do"		

*------------------------------------------------------------------------------
* APPENDIX: Consultation Waiting Time and Patient Information Implementation
*------------------------------------------------------------------------------
use "$data_final/LSS_info_DocPat_analysis_datasets_allcont.dta", clear

	include "$dofiles_tab/Appendix/pat_implementation.do"		

*------------------------------------------------------------------------------
* APPENDIX: Selection into Sample by Treatment
*------------------------------------------------------------------------------
use "$data_final/LSS_info_DocPat_analysis_datasets_allcont.dta", clear

	include "$dofiles_tab/Appendix/sample_selection.do"		
	
*------------------------------------------------------------------------------
* APPENDIX: Demographic Characteristics and Randomization Verification
*------------------------------------------------------------------------------
use "$data_final/LSS_info_DocPat_analysis_datasets_allcont.dta", clear

	include "$dofiles_tab/Appendix/pat_balance.do"		

*------------------------------------------------------------------------------
* APPENDIX: Predicting RDT Positivity With Observables	
*------------------------------------------------------------------------------
use "$data_final/LSS_info_DocPat_analysis_datasets_allcont.dta", clear

	include "$dofiles_tab/Appendix/mal_prob_probit.do"		

*------------------------------------------------------------------------------
* APPENDIX: Effect of Extended Provider Training on the Allocation of Malaria Treatment
*------------------------------------------------------------------------------
use "$data_final/LSS_info_DocPat_analysis_datasets_allcont.dta", clear

	include "$dofiles_tab/Appendix/doc_treat_allocn_inter.do"		

*------------------------------------------------------------------------------
* APPENDIX: Impacts of Extended Provider Training and Patient Information on Other Aspects of Care	
*------------------------------------------------------------------------------
use "$data_final/LSS_info_DocPat_analysis_datasets_allcont.dta", clear

	include "$dofiles_tab/Appendix/doc_num_meds.do"		
	
*------------------------------------------------------------------------------
* APPENDIX: Effect of Extended Provider Training and Patient Information on Satisfaction Index Components
*------------------------------------------------------------------------------
use "$data_final/LSS_info_DocPat_analysis_datasets_allcont.dta", clear

	include "$dofiles_tab/Appendix/doc_patient_satisfaction_comp.do"		

*------------------------------------------------------------------------------
* APPENDIX: Effect of Extended Provider Training and Patient Information on Patient Satisfaction
*------------------------------------------------------------------------------
use "$data_final/LSS_info_DocPat_analysis_datasets_allcont.dta", clear

	include "$dofiles_tab/Appendix/doc_patient_satisfaction_inter.do"		

*------------------------------------------------------------------------------
* APPENDIX: Effect of Extended Provider Training on Match Between Patient Prior and Prescription by Accuracy of Pre-Consultation Malaria Beliefs
* With and w/o additional controls
*------------------------------------------------------------------------------
use "$data_final/LSS_info_DocPat_analysis_datasets_allcont.dta", clear

	include "$dofiles_tab/Appendix/got_wanted_priorhet_match.do"		

	